<?php
if ( ! class_exists( 'IPPtak_Factory_Page' ))
{
  /**
   * Viewer class
   *
   * @package wp-page-takeover
   * @author InstaProduct
   * @link http://insta-product.com/
   */

  class IPPtak_Factory_Page
  {
    //{{ __construct

    /**
     * Class constructor
     *
     * @return void
     */
    public function __construct()
    {
    }

    //}}
    //{{ render

    /**
     * Render page
     *
     * @return string
     */
    public function render()
    {
      global $wp_query, $user_ID;
      if ( ( isset( $wp_query->query['ipptak'] ) && isset( $wp_query->query['promo_name'] ) ) ||
           isset( $wp_query->query['promo_id'] ) )
      {
        $page = $wp_query->post;

        if ( $page->post_status == 'publish' )
        {
          $setting = new IPPtak_Setting( $page->ID, '__ipptak-page-setting' );
          //
          //Check restricted
          if ( empty( $user_ID ) && $setting->getSetting( 'restricted', 'true' ) == 'true' )
          {
            $redirect  = $this->pageurl;
            $login_url = wp_login_url( $redirect );
            wp_redirect( $login_url );
            exit;
          }

          $this->query     = $wp_query;
          $this->setting   = $setting;
          $this->page      = $page;
          $this->cssurl    = IPPTAK_BASE_URL . 'assets/css/';
          $this->jsurl     = IPPTAK_BASE_URL . 'assets/js/';
          $this->imgurl    = IPPTAK_BASE_URL . 'assets/img/';
          $this->permalink = $this->_getPermalink( $page );
          $this->pageTitle = $this->_getPageTitle( $page );

          //Get bar & box
          $bar = $box = false;

          if ( $barId = $setting->getSetting( 'page_bar' ) ) {
            $bar = get_post( $barId );
          }
          if ( $boxId = $setting->getSetting( 'page_box' ) ) {
            $box = get_post( $boxId );
          }
          $this->bar        = $bar;
          $this->barSetting = new IPPtak_Setting( $bar->ID, '__ipptak-bar-setting' );
          $this->box        = $box;
          $this->boxSetting = new IPPtak_Setting( $box->ID, '__ipptak-box-setting' );

          //Save stat
          $this->_saveStat();

          //Render view
          $this->view( 'front/page/main' );
          exit;
        }
        else
        {
          $query->query_vars['post_type'] = 'ipptak-item-nothing';
        }
      }
    }

    //}}
    //{{ _getPermalink

    /**
     * Get page permalink
     *
     * @param object $page
     * @return void
     */
    protected function _getPermalink( $page )
    {
      if ( get_option( 'permalink_structure' ) )  {
        $base = get_option( '__ipptak_base_path', 'promo' );
        $link = get_home_url() . "/$base/" . $page->post_name;
      } else {
        $link = get_home_url() . '/?promo_id=' . $page->ID;
      }
      return $link;
    }

    //}}
    //{{ _getPageTitle

    /**
     * Get page title
     *
     * @param object $page
     * @return void
     */
    protected function _getPageTitle( $page )
    {
      $title = $this->setting->getSetting( 'seo_meta_title' );
      $title = trim( $title );
      if ( empty( $title )) {
          $title = $this->page->post_title;
      }
      $title = stripslashes( $title );
      return $title;
    }

    //}}
    //{{ getShareLink

    /**
     * Get share link
     *
     * @param  string $type
     * @return string
     */
    public function getShareLink( $type )
    {
      $pagetitle = urlencode( $this->pageTitle );
      $pageurl   = urlencode( $this->permalink );
      $actions   =  array(
        'facebook'      => 'http://www.facebook.com/share.php?u=' . $pageurl,
        'twitter'       => 'https://twitter.com/share?url=' . $pageurl . '&text=' . $pagetitle,
        'googleplus'    => 'https://plusone.google.com/_/+1/confirm?hl=en&url=' . $pageurl,
        'pinterest'     => 'http://pinterest.com/pin/create/button/?url=' . $pageurl . '&media=&description=' . $pagetitle,
        'linkedin'      => 'http://www.linkedin.com/shareArticle?mini=true&url=' . $pageurl .'&title=' . $pagetitle,
        'tumblr'        => 'http://www.tumblr.com/share?v=3&u=' . $pageurl,
        'stumbleupon'   => 'http://www.stumbleupon.com/submit?url=' . $pageurl . '&title=' . $pagetitle,
        'digg'          => 'http://digg.com/submit?url=' . $pageurl . '&title=' . $pagetitle,
        'email'         => 'mailto:?subject=' . $pagetitle
      );
      $link = '#';
      if ( array_key_exists( $type, $actions )) {
        $link = $actions[$type];
      }
      return $link;
    }

    //}}
    //{{ getGoogleFont

    /**
     * Get Google font
     *
     * @return string
     */
    public function getGoogleFont()
    {
        $fonts   = array();
        $fonts[] = $this->setting->getSetting( 'header_font_family', 'roboto' );
        $fonts[] = $this->setting->getSetting( 'footer_font_family', 'roboto' );
        $fonts[] = $this->setting->getSetting( 'main_font_family', 'roboto' );
        $fonts   = array_unique( $fonts );

        $fams  = array();
        $links = IPPtak_Font::getLinks();
        foreach( $fonts as $font )
        {
            if ( array_key_exists( $font, $links ))
            {
                $fams[] = $links[$font];
            }
        }

        $family  = implode( '|', $fams );
        $url     = 'http://fonts.googleapis.com/css?family=' . $family;
        return $url;
    }

    //}}
    //{{ getCountdownFormat

    /**
     * Get countdown format
     *
     * @param  array $setting
     * @return string
     */
    public function getCountdownFormat( $setting )
    {
      $search = array(
        'y', 'm', 'w', 'd', 'h', 'i', 's'
      );
      $replace = array(
        '%Y', '%m', '%W', '%d', '%H', '%M', '%S'
      );
      $string = $setting->getSetting( 'countdown_format', 'y_m_d_h_i_s' );
      $format = str_replace( $search, $replace, $string );
      $format = str_replace( '_', ':', $format );
      return $format;
    }

    //}}
    //{{ getCountdownLabels

    /**
     * Get countdown labels
     *
     * @param  array $setting
     * @return string
     */
    public function getCountdownLabels( $setting )
    {
      $search = array(
        'y', 'm', 'w', 'd', 'h', 'i', 's'
      );
      $replace = array(
        'years', 'months', 'weeks', 'days', 'hours', 'minutes', 'seconds'
      );
      $string = $setting->getSetting( 'countdown_format', 'y_m_d_h_i_s' );
      $labels = str_replace( $search, $replace, $string );
      return $labels;
    }

    //}}
    //{{ getYoutubeUrl

    /**
     * Get youtube url
     *
     * @return string
     */
    public function getYoutubeUrl( $setting )
    {
      $url  = $setting->getSetting( 'box_video_url' );
      $time = $setting->getSetting( 'box_video_start', 0 );
      $auto = $setting->getSetting( 'box_video_autoplay', 'false' );
      if ( $url )
      {
        if ( strpos( $url, 'embed' ) === false ) {
          if ( strpos( $url, 'watch' ) !== false ) {
            $id     = '';
            $parsed = parse_url( $url );
            if ( ! empty( $parsed['query'] )) {
                parse_str( $parsed['query'], $args );
                if ( ! empty( $args['v'] )) {
                    $id = $args['v'];
                }
            }
            $url = 'http://youtube.com/embed/' . $id;
          }
          elseif ( strpos( $url, 'youtu.be' ) !== false ) {
            $id     = '';
            $parsed = parse_url( $url );
            if ( ! empty( $parsed['path'] )) {
              $id = trim( $parsed['path'], '/' );
            }
            $url = 'http://youtube.com/embed/' . $id;
          }
        }
        if ( $auto == 'true' ) {
          $astart = 1;
        } else {
          $astart = 0;
        }
        $url .= '?autoplay=' . $astart . '&rel=0';
        if ( ! empty( $time )) {
          $url .= '&start=' . $time;
        }
      }
      return $url;
    }

    //}}
    //{{ displayWidget

    /**
     * Memeriksa apakah akan menampilkan widget
     *
     * @param  object $widget
     * @param  object $setting
     * @return void
     */
    protected function displayWidget( $widget, $setting )
    {
      global $user_ID;

      $status = true;
      //
      //Check restricted
      $restricted = false;
      if ( empty( $user_ID ) && $setting->getSetting( 'restricted', 'true' ) == 'true' ) {
        $restricted = true;
      }

      if ( $widget && $widget->post_status == 'publish' && ! $restricted )
      {
        if ( $setting->getSetting( 'countdown_activate' ) == 'true' )
        {
          $endDate = $setting->getSetting( 'countdown_target_date' );
          $endTime = $setting->getSetting( 'countdown_target_time' );
          $end     = $endDate . ' ' . $endTime;

          $timeTarget = strtotime( $end );
          $timeNow    = time();

          if ( $timeNow > $timeTarget ) {
            $status = false;
          }
        }
      }
      return $status;
    }

    //}}
    //{{ _saveStat

    /**
     * Save stat
     *
     * @return void
     */
    protected function _saveStat()
    {
      $model = new IPPtak_Model_Stat();
      $model->saveStat( $this->page, 'view' );
    }

    //}}
    //{{ view

    /**
     * Get admin view file
     *
     * @param string $filename
     * @return void
     */
    public function view( $filename )
    {
      $path  = IPPTAK_VIEW;
      $path .= strtolower( $filename ) . '.php';
      if ( file_exists( $path )) {
        include( $path );
      }
    }

    //}}
  }
}
