<?php
/**
 * Main application class
 *
 * @package wp-page-takeover
 * @author InstaProduct
 * @link http://insta-product.com/
 */

//
//Include all function files
require_once( IPPTAK_LIB . '/config.php' );
require_once( IPPTAK_LIB . '/setting.php' );
require_once( IPPTAK_LIB . '/options.php' );
require_once( IPPTAK_LIB . '/db.php' );
require_once( IPPTAK_LIB . '/font.php' );
require_once( IPPTAK_LIB . '/faicon.php' );
require_once( IPPTAK_LIB . '/tableMain.php' );
require_once( IPPTAK_LIB . '/tableBox.php' );
require_once( IPPTAK_LIB . '/tablePage.php' );
require_once( IPPTAK_LIB . '/factoryPage.php' );
require_once( IPPTAK_LIB . '/factoryWidget.php' );
require_once( IPPTAK_LIB . '/modelBar.php' );
require_once( IPPTAK_LIB . '/modelBox.php' );
require_once( IPPTAK_LIB . '/modelPage.php' );
require_once( IPPTAK_LIB . '/modelStat.php' );
require_once( IPPTAK_APP . '/controller.php' );
require_once( IPPTAK_APP . '/viewer.php' );

if ( ! class_exists( 'IPPtak_App' ))
{
  class IPPtak_App
  {
    //{{ run

    /**
     * Run all functions
     *
     * @return void
     */
    public static function run()
    {
      $hook = sanitize_title( IPPTAK_TITLE );

      //Install Plugin
      register_activation_hook( __FILE__, array( __CLASS__, 'install' ) );

      //Hook for plugin loaded
      add_action( 'plugins_loaded', array( __CLASS__, 'updateDb' ) );

      //
      //Admin init
      add_action( 'admin_init', array( __CLASS__, 'adminInit' ) );

      //
      //Register post type
      add_action( 'init', array( __CLASS__, 'registerPostType' ) );

      //
      //Register admin menu
      add_action( 'admin_menu', array( __CLASS__, 'addAdminMenu' ) );

      //
      // Add meta box option
      //
      add_action( 'add_meta_boxes', array( __CLASS__, 'addMetaBox' ) );
      add_action( 'save_post', array( __CLASS__, 'savePost' ) );

      //Add bar via meta box
      add_action( 'wp_footer', array( __CLASS__, 'factoryWidget' ) );

      //
      //Rewrite Handler
      //
      add_action( 'init', array( __CLASS__, 'rewriteFlush' ) );
      add_action( 'pre_get_posts', array( __CLASS__, 'init' ) );

      //Render page
      add_action( 'template_redirect', array( __CLASS__, 'factoryPage' ) );

      //
      //Add css
      add_action( 'admin_print_styles-toplevel_page_' . IPPTAK_PAGENAME, array( __CLASS__, 'adminStyle' ), 1100 );
      add_action( 'admin_print_styles-'.$hook.'_page_' . IPPTAK_PAGENAME . '-box', array( __CLASS__, 'adminStyle' ), 1100 );
      add_action( 'admin_print_styles-'.$hook.'_page_' . IPPTAK_PAGENAME . '-page', array( __CLASS__, 'adminStyle' ), 1100 );
      add_action( 'admin_print_styles-'.$hook.'_page_' . IPPTAK_PAGENAME . '-setting', array( __CLASS__, 'adminStyle' ), 1100 );
      add_action( 'admin_print_styles', array( __CLASS__, 'adminGlobalStyle' ), 1000 );

      //
      //Add javascript
      add_action( 'admin_print_scripts-toplevel_page_' . IPPTAK_PAGENAME, array( __CLASS__, 'adminScript' ), 1100 );
      add_action( 'admin_print_scripts-'.$hook.'_page_' . IPPTAK_PAGENAME . '-box', array( __CLASS__, 'adminScript' ), 1100 );
      add_action( 'admin_print_scripts-'.$hook.'_page_' . IPPTAK_PAGENAME . '-page', array( __CLASS__, 'adminScript' ), 1100 );
      add_action( 'admin_print_scripts-'.$hook.'_page_' . IPPTAK_PAGENAME . '-setting', array( __CLASS__, 'adminScript' ), 1100 );
      add_action( 'admin_print_scripts', array( __CLASS__, 'adminGlobalScript' ), 1000 );

      //
      //Front style & script
      add_action('wp_head', array( __CLASS__, 'publicStyle' ) );

      if ( ! is_admin() ) {
        add_action('wp_enqueue_scripts', array( __CLASS__, 'publicScript' ), 10 );
      }
    }

    //}}
    //{{ install

    /**
     * Install plugin
     *
     * @return void
     */
    public static function install()
    {
      //Install DB
      $db = new IPPtak_Db();
      $db->install();
    }

    //}}
    //{{ updateDb

    /**
     * Update Db
     *
     * @return void
     */
    public static function updateDb()
    {
      $db = new IPPtak_Db();
      $db->update();
    }

    //}}
    //{{ adminInit

    /**
     * Admin init
     *
     * @return void
     */
    public static function adminInit()
    {
      /**
       * Ajax handler
       **/
      $controller = new IPPtak_Controller();
      $controller->ajax();
    }

    //}}
    //{{ addAdminMenu

    /**
     * Add admin menu
     *
     * @return void
     */
    public static function addAdminMenu()
    {
      add_menu_page(
        IPPTAK_TITLE,
        IPPTAK_TITLE,
        'edit_posts',
        IPPTAK_PAGENAME,
        array( __CLASS__, 'dashboard' ),
        'dashicons-admin-page'
      );
      add_submenu_page(
        IPPTAK_PAGENAME,
        __( 'My Bars', IPPTAK_SLUG ),
        __( 'My Bars', IPPTAK_SLUG ),
        'edit_posts',
        IPPTAK_PAGENAME,
        array( __CLASS__, 'dashboard' )
      );
      add_submenu_page(
        IPPTAK_PAGENAME,
        __( 'My Boxes', IPPTAK_SLUG ),
        __( 'My Boxes', IPPTAK_SLUG ),
        'edit_posts',
        IPPTAK_PAGENAME . '-box',
        array( __CLASS__, 'box' )
      );
      add_submenu_page(
        IPPTAK_PAGENAME,
        __( 'My Pages', IPPTAK_SLUG ),
        __( 'My Pages', IPPTAK_SLUG ),
        'edit_posts',
        IPPTAK_PAGENAME . '-page',
        array( __CLASS__, 'page' )
      );
      add_submenu_page(
        IPPTAK_PAGENAME,
        __( 'Settings', IPPTAK_SLUG ),
        __( 'Settings', IPPTAK_SLUG ),
        'edit_posts',
        IPPTAK_PAGENAME . '-setting',
        array( __CLASS__, 'setting' )
      );
    }

    //}}
    //{{ dashboard

    /**
     * Add administrator my bars page
     *
     * @return void
     */
    public static function dashboard()
    {
      $viewer = new IPPtak_Viewer();
      $viewer->dashboard();
    }

    //}}
    //{{ box

    /**
     * Add administrator my boxes page
     *
     * @return void
     */
    public static function box()
    {
      $viewer = new IPPtak_Viewer();
      $viewer->box();
    }

    //}}
    //{{ page

    /**
     * Add administrator my pages page
     *
     * @return void
     */
    public static function page()
    {
      $viewer = new IPPtak_Viewer();
      $viewer->page();
    }

    //}}
    //{{ setting

    /**
     * Add administrator setting page
     *
     * @return void
     */
    public static function setting()
    {
      $viewer = new IPPtak_Viewer();
      $viewer->setting();
    }

    //}}
    //{{ registerPostType

    /**
     * Register Post Type
     *
     * @return void
     */
    public static function registerPostType()
    {
      $args  = array(
        'public' => false
      );
      register_post_type( 'ipptak_bar', $args );
      register_post_type( 'ipptak_box', $args );
      register_post_type( 'ipptak_page', $args );
    }

    //}}
    //{{ addMetaBox

    /**
     * Add administrator meta box
     *
     * @return void
     */
    public static function addMetaBox()
    {
        //
        //Add post/page metabox
        $screens = array( 'post', 'page' );
        foreach ($screens as $screen)
        {
            add_meta_box(
                'ipptak_metabox',
                __( 'WP Page Takeover Settings', IPPTAK_SLUG ),
                array( __CLASS__, 'metaBoxContent' ),
                $screen
            );
        }
    }

    //}}
    //{{ metaBoxContent

    /**
     * Content for administrator meta box
     *
     * @return void
     */
    public static function metaBoxContent( $post )
    {
        $viewer = new IPPtak_Viewer();
        $viewer->metabox( $post );
    }

    //}}
    //{{ savePost

    /**
     * Save page/post meta box setting
     *
     * @return void
     */
    public static function savePost( $post_id )
    {
        if ( isset( $_POST['post_type'] ) && 'page' == $_POST['post_type'] ) {
            if ( ! current_user_can( 'edit_page', $post_id ) ) {
                return;
            }
        } else {
            if ( ! current_user_can( 'edit_post', $post_id ) ) {
                return;
            }
        }
        // Check if the user intended to change this value.
        if ( ! isset( $_POST['ipptak_mbox_nonce'] ) ) {
            return;
        }
        $post_ID  = $_POST['post_ID'];
        //Bar
        $barId = sanitize_text_field( $_POST['ipptak_post_bar'] );
        update_post_meta( $post_ID, '__ipptak_post_bar', $barId );
        //Box
        $boxId = sanitize_text_field( $_POST['ipptak_post_box'] );
        update_post_meta( $post_ID, '__ipptak_post_box', $boxId );
    }

    //}}
    //{{ init

    /**
     * Init request
     *
     * @return void
     */
    public static function init( $query )
    {
      $q = $query->query;
      if ( isset( $q['ipptak'] ) && isset( $q['promo_name'] )) {
        $query->query_vars['post_type'] = 'ipptak_page';
        $query->query_vars['name']      = $q['promo_name'];
        $query->query_vars['pagename']  = $q['promo_name'];
        $query->query['pagename']       = $q['promo_name'];

      } elseif( isset( $q['promo_id'] )) {
        $query->query_vars['post_type'] = 'ipptak_page';
        $query->query_vars['p']         = absint( $q['promo_id'] );
      }
    }

    //}}
    //{{ rewriteInit

    /**
     * Init rewrite rule
     *
     * @return void
     */
    public static function rewriteInit()
    {
      $base = get_option( '__ipptak_base_path', 'promo' );
      add_rewrite_rule(
       $base . '/([^/]+)/?$',
       'index.php?ipptak=1&promo_name=$matches[1]',
       'top'
      );
      add_rewrite_rule(
       $base . '/([^/]+)/feed/(feed|rdf|rss|rss2|atom)/?$',
       'index.php?ipptak=1&promo_name=$matches[1]&feed=$matches[2]',
       'top'
      );
      add_rewrite_rule(
        $base . '/([^/]+)/(feed|rdf|rss|rss2|atom)/?$',
        'index.php?ipptak=1&promo_name=$matches[1]&feed=$matches[2]',
        'top'
      );
      add_rewrite_rule(
        $base . '/([^/]+)/page/?([0-9]{1,})/?$',
        'index.php?ipptak=1&promo_name=$matches[1]&paged=$matches[2]',
        'top'
      );
      add_rewrite_tag( '%promo_name%', '([a-zA-Z0-9\_])');
      add_rewrite_tag( '%promo_id%', '([0-9])');
      add_rewrite_tag( '%ipptak%', '([1])');
    }

    //}}
    //{{ rewriteFlush

    /**
     * Flush rewrite rule
     *
     * @return void
     */
    public static function rewriteFlush()
    {
      $base = get_option( '__ipptak_base_path', 'promo' );
      $old  = get_option( '__ipptak_base_path_old', 'promo' );

      self::rewriteInit();

      if ( $base != $old ) {
         flush_rewrite_rules();
         update_option( '__ipptak_base_path_old', $base );
      }
    }

    //}}
    //{{ factoryPage

    /**
     * Render promo page
     *
     * @return void
     */
    public static function factoryPage()
    {
      //Factory
      $factory = new IPPtak_Factory_Page();
      $factory->render();
    }

    //}}
    //{{ factoryWidget

    /**
     * Render promo page
     *
     * @return void
     */
    public static function factoryWidget()
    {
      //Factory
      $factory = new IPPtak_Factory_Widget();
      $factory->render();
    }


    //}}
    //{{ adminStyle

    /**
     * Add Css file
     *
     * @return void
     */
    public static function adminStyle()
    {
      wp_deregister_style( 'ipptak-admin-style' );
      wp_register_style('ipptak-admin-style', IPPTAK_BASE_URL . 'assets/css/admin.min.css', false, null);
      wp_enqueue_style('ipptak-admin-style');

      wp_deregister_style( 'ipptak-datetime-style' );
      wp_register_style('ipptak-datetime-style', IPPTAK_BASE_URL . 'assets/css/jquery.datetimepicker.css', false, null);
      wp_enqueue_style('ipptak-datetime-style');
    }

    //}}
    //{{ adminGlobalStyle

    /**
     * Add Css file to all pages
     *
     * @return void
     */
    public static function adminGlobalStyle()
    {
      wp_deregister_style( 'ipptak-admin-global-style' );
      wp_register_style('ipptak-admin-global-style', IPPTAK_BASE_URL . 'assets/css/admin-global.min.css', false, null);
      wp_enqueue_style('ipptak-admin-global-style');
    }

    //}}
    //{{ adminScript

    /**
     * Add javascript file
     *
     * @return void
     */
    public static function adminScript()
    {
    ?>
      <script type="text/javascript">
        var ipptak_img_url = '<?php echo IPPTAK_BASE_URL . 'assets/img/'; ?>',
          ui_base_image  = '<?php echo IPPTAK_BASE_URL . 'assets/img/'; ?>',
          ui_message     =
          {
            delete_confirm_title: '<?php _e( 'Delete Confirmation', IPPTAK_SLUG ); ?>',
            delete_confirm_info: '<?php _e( 'Are you sure doing this action?', IPPTAK_SLUG ); ?>'
          }
      </script>

      <?php
      wp_deregister_script('jquery-ui');
      wp_register_script('jquery-ui', "http" . ($_SERVER['SERVER_PORT'] == 443 ? "s" : "") . "://ajax.googleapis.com/ajax/libs/jqueryui/1.10.4/jquery-ui.min.js", false, null);
      wp_enqueue_script('jquery-ui');

      wp_deregister_script('ipptak-admin-script');
      wp_enqueue_script(
        'ipptak-admin-script',
        IPPTAK_BASE_URL . 'assets/js/admin.js',
        array( 'jquery' ),
        1,
        true
      );
    }

    //}}
    //{{ adminGlobalScript

    /**
     * Add javascript file to all pages
     *
     * @return void
     */
    public static function adminGlobalScript()
    {
      wp_deregister_script('ipptak-admin-global-script');
      wp_enqueue_script(
        'ipptak-admin-global-script',
        IPPTAK_BASE_URL . 'assets/js/admin-global.min.js',
        array( 'jquery' ),
        1,
        true
      );
    }

    //}}
    //{{ publicStyle

    /**
     * Print public style
     *
     * @return void
     */
    public static function publicStyle()
    {
    ?>
      <script type="text/javascript">
        var ipptak_ajaxurl  = "<?php echo admin_url( 'admin-ajax.php' ); ?>";
        var ipptak_img_url  = '<?php echo IPPTAK_BASE_URL . 'assets/img/'; ?>';
      </script>
      <link media="all" type="text/css" href="<?php echo IPPTAK_BASE_URL; ?>assets/css/public.min.css" rel="stylesheet">

    <?php
    }

    //}}
    //{{ publicScript

    /**
     * Print public script
     *
     * @return void
     */
    public static function publicScript()
    {
      wp_enqueue_script('jquery');

      wp_deregister_script('jquery-ui');
      wp_register_script('jquery-ui', "http" . ($_SERVER['SERVER_PORT'] == 443 ? "s" : "") . "://ajax.googleapis.com/ajax/libs/jqueryui/1.10.4/jquery-ui.min.js", false, null);
      wp_enqueue_script('jquery-ui');

      wp_deregister_script('lodash');
      wp_register_script('lodash', "http" . ($_SERVER['SERVER_PORT'] == 443 ? "s" : "") . "://cdn.jsdelivr.net/lodash/4.6.1/lodash.min.js", false, null);
      wp_enqueue_script('lodash');

      wp_deregister_script('ipptak-public-script');
      wp_enqueue_script(
        'ipptak-public-script',
        IPPTAK_BASE_URL . 'assets/js/public.min.js',
        array( 'jquery' ),
        1,
        true
      );
    }

    //}}
  }
}
