<?php
if ( ! class_exists( 'IPPtak_Factory_Widget' ))
{
  /**
   * Widget factory class
   *
   * @package wp-page-takeover
   * @author InstaProduct
   * @link http://insta-product.com/
   */

  class IPPtak_Factory_Widget extends IPPtak_Factory_Page
  {
    //{{ __construct

    /**
     * Class constructor
     *
     * @return void
     */
    public function __construct()
    {
    }

    //}}
    //{{ render

    /**
     * Render page
     *
     * @return string
     */
    public function render()
    {
      $bar = $this->_getPostBar();
      $box = $this->_getPostBox();

      if ( $bar && $bar->post_status == 'publish' )
      {
        $this->bar        = $bar;
        $this->barSetting = new IPPtak_Setting( $bar->ID, '__ipptak-bar-setting' );

        //Render view
        if ( $this->_checkCountdown( $this->barSetting ) ) {
          $this->view( 'front/bar/main' );
        }
      }
      if ( $box && $box->post_status == 'publish' )
      {
        $this->box        = $box;
        $this->boxSetting = new IPPtak_Setting( $box->ID, '__ipptak-box-setting' );
        //Render view
        if ( $this->_checkCountdown( $this->boxSetting ) ) {
          $this->view( 'front/box/main' );
        }
      }
    }

    //}}
    //{{ previewBar

    /**
     * Bar preview viewer
     *
     * @param  array $bar
     * @return void
     */
    public function previewBar( $bar )
    {
      $output = '';
      if ( $bar )
      {
        $this->bar        = $bar;
        $this->isPreview  = true;
        $this->barSetting = new IPPtak_Setting( $bar->ID, '__ipptak-bar-setting' );
        //Render view
        ob_start();
        $this->view( 'front/bar/main' );
        $output = ob_get_contents();
        ob_end_clean();
      }
      echo $output;
    }

    //}}
    //{{ previewBox

    /**
     * Box preview viewer
     *
     * @param  array $box
     * @return void
     */
    public function previewBox( $box )
    {
      $output = '';
      if ( $box )
      {
        $this->box        = $box;
        $this->isPreview  = true;
        $this->boxSetting = new IPPtak_Setting( $box->ID, '__ipptak-box-setting' );
        //Render view
        ob_start();
        $this->view( 'front/box/main' );
        $output = ob_get_contents();
        ob_end_clean();
      }
      echo $output;
    }

    //}}
    //{{ _getPostBar

    /**
     * Get post bar
     *
     * @return void
     */
    protected function _getPostBar()
    {
      global $post;

      $barId   = 0;
      $bar     = false;
      $type    = '';
      $general = get_option( '__ipptak_general_bar' );
      if ( ! empty( $general )) {
        $barId = absint( $general );
        $type  = 'general';
      }
      else
      {
        if ( ( is_page() || is_single() ) && ! empty( $post )) {
          $barId = get_post_meta( $post->ID, '__ipptak_post_bar', true );
          $type  = 'page';
        } elseif ( is_home() ) {
          $barId = get_option( '__ipptak_home_bar' );
          $type  = 'home';
        }
      }
      if ( ! empty( $barId )) {
        $bar = get_post( $barId );
      }
      return $bar;
    }

    //}}
    //{{ _getPostBox

    /**
     * Get post box
     *
     * @return void
     */
    protected function _getPostBox()
    {
      global $post;

      $boxId   = 0;
      $box     = false;
      $type    = '';
      $general = get_option( '__ipptak_general_box' );
      if ( ! empty( $general )) {
        $boxId = absint( $general );
        $type  = 'general';
      }
      else
      {
        if ( ( is_page() || is_single() ) && ! empty( $post )) {
          $boxId = get_post_meta( $post->ID, '__ipptak_post_box', true );
          $type  = 'page';
        } elseif ( is_home() ) {
          $boxId = get_option( '__ipptak_home_box' );
          $type  = 'home';
        }
      }
      if ( ! empty( $boxId )) {
        $box = get_post( $boxId );
      }
      return $box;
    }

    //}}
    //{{ _checkCountdown

    /**
     * Memeriksa countdown
     *
     * @param  array $setting
     * @return void
     */
    protected function _checkCountdown( $setting )
    {
      global $user_ID;

      //
      //Check restricted
      $restricted = false;
      if ( empty( $user_ID ) && $setting->getSetting( 'restricted', 'true' ) == 'true' ) {
        $restricted = true;
      }
      if ( $restricted ) {
        return false;
      }

      $status = true;
      if ( $setting->getSetting( 'countdown_activate' ) == 'true' )
      {
        $endDate = $setting->getSetting( 'countdown_target_date' );
        $endTime = $setting->getSetting( 'countdown_target_time' );
        $end     = $endDate . ' ' . $endTime;

        $timeTarget = strtotime( $end );
        $timeNow    = time();

        if ( $timeNow > $timeTarget ) {
          $status = false;
        }
      }
      return $status;
    }

    //}}
  }
}
