<?php
/**
 * Class model stat
 *
 * @package wp-page-takeover
 * @author InstaProduct
 * @link http://insta-product.com/
 */

if ( ! class_exists( 'IPPtak_Model_Stat' ))
{
  /**
   * Class for manage post setting
   */
  class IPPtak_Model_Stat
  {
    /**
     * Get stats
     *
     * @return array
     */
    public function getStats()
    {
      global $wpdb;

      $table = $wpdb->prefix . 'ipptak_stats';
      $sql   = "
          SELECT *
          FROM `$table`
      ";
      $results = $wpdb->get_results( $sql );
      return $results;
    }

    /**
     * Get stat
     *
     * @param  int $stat_id
     * @return array
     */
    public function getStat( $stat_id )
    {
      global $wpdb;

      $stat_id = absint( $stat_id );
      $table   = $wpdb->prefix . 'ipptak_stats';
      $sql     = "
          SELECT *
          FROM `$table` WHERE stat_id = %d
      ";
      $query   = $wpdb->prepare( $sql, $stat_id );
      $results = $wpdb->get_row( $query );
      return $results;
    }

    /**
     * Get stat value
     *
     * @param  int    $page_id
     * @param  string $type
     * @return array
     */
    public function getStatValue( $page_id, $type )
    {
      $count = 0;
      if ( $stat = $this->getStatBypage( $page_id )) {
        if ( isset( $stat->$type )) {
          $count = (int)$stat->$type;
        }
      }
      return $count;
    }

    /**
     * Get stat by page
     *
     * @param  int $page_id
     * @return array
     */
    public function getStatBypage( $page_id )
    {
      global $wpdb;

      $page_id = absint( $page_id );
      $table   = $wpdb->prefix . 'ipptak_stats';
      $sql     = "
          SELECT
              SUM( `stat_view` ) AS `view`,
              SUM( `stat_click` ) AS `click`,
              SUM( `stat_share` ) AS `share`
          FROM `$table` WHERE page_id = %d
      ";
      $query   = $wpdb->prepare( $sql, $page_id );
      $results = $wpdb->get_row( $query );
      return $results;
    }

    /**
     * Get stat by page date
     *
     * @param  int    $page_id
     * @param  string $date
     * @return array
     */
    public function getStatBypageDate( $page_id, $date )
    {
      global $wpdb;

      $page_id = absint( $page_id );
      $table   = $wpdb->prefix . 'ipptak_stats';
      $sql     = "
          SELECT *
          FROM `$table`
          WHERE page_id = $page_id and stat_date = '$date'
      ";
      $results = $wpdb->get_row( $sql );
      return $results;
    }

    /**
     * Get statistic data
     *
     * @return array
     */
    public function getStatisticData( $page_id, $type, $start = null, $end = null )
    {
      global $wpdb;

      $page_id = absint( $page_id );
      $table   = $wpdb->prefix . 'ipptak_stats';
      $query   = "
          SELECT
              DATE_FORMAT(stat_date, '%Y-%m-%d') AS gdate,";
      //Type value
      if ( $type == 'view' ) {
        $query .= 'SUM(stat_view) AS value';
      } elseif ( $type == 'click' ) {
        $query .= 'SUM(stat_click) AS value';
      } elseif ( $type == 'share' ) {
        $query .= 'SUM(stat_share) AS value';
      }
      $query .= " FROM $table
                  WHERE page_id = $page_id";

      if ( ! empty( $start ) && ! empty( $end ))
      {
        if ( $start == $end ) {
          $query .= " AND DATE_FORMAT( stat_date, '%Y-%m-%d' ) = '$start'";
        } else {
          $query .= " AND stat_date BETWEEN '$start' AND '$end'";
        }
      }
      elseif ( ! empty( $start )) {
        $query .= " AND DATE_FORMAT( stat_date, '%Y-%m-%d' ) = '$start'";
      }
      elseif ( ! empty( $end )) {
        $query .= " AND DATE_FORMAT( stat_date, '%Y-%m-%d' ) = '$end'";
      }
      $query .= " GROUP BY gdate";
      $results = $wpdb->get_results( $query );
      return $results;
    }

    /**
     * Do save statistic
     *
     * @param object $page
     * @param string $type
     * @param int    $count
     * @return void
     */
    public function saveStat( $page, $type, $count = 1 )
    {
      $_types = array(
        'view',
        'click',
        'share'
      );
      $key = 'stat_';
      if ( in_array( $type, $_types )) {
        $key .= $type;
      }
      $date = date( 'Y-m-d 00:00:00' );
      $data = array();
      if ( $stat = $this->getStatBypageDate( $page->ID, $date ))
      {
        $ccount = 0;
        if ( isset( $stat->$key )) {
          $ccount = $stat->$key;
        }
        $data[$key] = $ccount + $count;
        $this->_updateStat( $stat->stat_id, $data );
      }
      else {
        $data['page_id']   = $page->ID;
        $data['stat_date'] = $date;
        $data[$key]        = $count;
        $this->_insertStat( $data );
      }
    }

    /**
     * Insert statistic data
     *
     * @param array $data
     * @return void
     */
    protected function _insertStat( $data )
    {
      global $wpdb;

      $table  = $wpdb->prefix . 'ipptak_stats';
      $data   = (array)$data;

      $result = $wpdb->insert( $table, $data );
      if ( $result ) {
        return $wpdb->insert_id;
      }
      return false;
    }

    /**
     * Update statistic data
     *
     * @param int   $id
     * @param array $data
     * @return void
     */
    protected function _updateStat( $id, $data )
    {
      global $wpdb;

      $table  = $wpdb->prefix . 'ipptak_stats';
      $data   = (array)$data;
      $where  = array(
        'stat_id' => absint( $id )
      );
      $result = $wpdb->update( $table, $data, $where );
      return $result;
    }

    /**
     * Restyle text
     *
     * @param  string $string
     * @return void
     */
    public function restyleText( $string )
    {
      $string = number_format( $string );
      $string_count = substr_count( $string, ',' );
      if( $string_count != '0' ) {
        if( $string_count == '1'){
          return substr( $string, 0, -4 ).'K';
        } else if( $string_count == '2' ){
          return substr( $string, 0, -8 ).'M';
        } else if( $string_count == '3' ){
          return substr( $string, 0,  -12 ).'B';
        } else {
          return;
        }
      } else {
        return $string;
      }
    }
  }
}
?>
