<?php
if ( ! class_exists( 'IPPtak_Viewer' ))
{
  /**
   * Viewer class
   *
   * @package wp-page-takeover
   * @author InstaProduct
   * @link http://insta-product.com/
   */

  class IPPtak_Viewer
  {
    //{{ dashboard

    /**
     * Dashboard viewer
     *
     * @return void
     */
    public function dashboard()
    {
      $this->pageId = IPPTAK_PAGENAME;

      //Create new box
      if ( isset( $_GET['action'] ) && $_GET['action'] == 'create' )
      {
        $this->_manageBar();
      }
      //Edit box
      elseif ( isset( $_GET['action'] ) && $_GET['action'] == 'edit' )
      {
        if ( empty( $_GET['id'] )) {
          wp_die( __('You attempted to edit an item that doesn&#8217;t exist. Perhaps it was deleted?', IPPTAK_SLUG ) );
        }
        $id = absint( $_GET['id'] );
        if ( ! $box = get_post( $id ) ) {
          wp_die( __('You attempted to edit an item that doesn&#8217;t exist. Perhaps it was deleted?', IPPTAK_SLUG ) );
        }
        $this->_manageBar( $box );
      }
      //Bar dashboard
      else {
        $this->view( 'admin/dashboard' );
      }
    }

    //}}
    //{{ _manageBar

    /**
     * Manage bar
     *
     * @param object $bar
     * @return void
     */
    protected function _manageBar( $bar = false )
    {
      //
      //Including script
      wp_enqueue_media();
      wp_enqueue_script('wp-color-picker');
      wp_enqueue_style('wp-color-picker');

      $barId = 0;
      if ( $bar ) {
        $barId = $bar->ID;
      }
      $setting    = new IPPtak_Setting( $barId, '__ipptak-bar-setting' );
      $formAction = admin_url( 'admin-ajax.php' ) . '?doajax=1&ipptak=1&action=update_bar';
      if ( $bar )
      {
        $pageTitle   = __( 'Edit Bar', IPPTAK_SLUG );
        $submitLabel = __( 'Save Change', IPPTAK_SLUG );
        $submitId    = 'ipptak-edit-bar';
        $formId      = 'ipptak-form-bar-update';
        $submitIcon  = 'floppy-o';
        $pageId      = IPPTAK_PAGENAME;

      } else
      {
        $pageTitle   = __( 'Add Bar', IPPTAK_SLUG );
        $submitLabel = __( 'Add Bar', IPPTAK_SLUG );
        $submitId    = 'ipptak-add-bar';
        $formId      = 'ipptak-form-bar-add';
        $submitIcon  = 'plus-circle';
        $pageId      = IPPTAK_PAGENAME;
      }
      $this->pageId      = $pageId;
      $this->pageTitle   = $pageTitle;
      $this->submitLabel = $submitLabel;
      $this->submitId    = $submitId;
      $this->formId      = $formId;
      $this->submitIcon  = $submitIcon;
      $this->setting     = $setting;
      $this->bar         = $bar;
      $this->barId       = $barId;
      $this->formAction  = $formAction;

      $tab = 'ipptak-section-general';
      if ( ! empty( $_REQUEST['tab'] )) {
        $tab = $_REQUEST['tab'];
      }
      $this->tab = $tab;

      //Render view
      $this->view( 'admin/bar/main' );
    }

    //}}
    //{{ box

    /**
     * Manage boxes viewer
     *
     * @return void
     */
    public function box()
    {
      $this->pageId = IPPTAK_PAGENAME . '-box';

      //Create new box
      if ( isset( $_GET['action'] ) && $_GET['action'] == 'create' )
      {
        $this->_manageBox();
      }
      //Edit box
      elseif ( isset( $_GET['action'] ) && $_GET['action'] == 'edit' )
      {
        if ( empty( $_GET['id'] )) {
          wp_die( __('You attempted to edit an item that doesn&#8217;t exist. Perhaps it was deleted?', IPPTAK_SLUG ) );
        }
        $id = absint( $_GET['id'] );
        if ( ! $box = get_post( $id ) ) {
          wp_die( __('You attempted to edit an item that doesn&#8217;t exist. Perhaps it was deleted?', IPPTAK_SLUG ) );
        }
        $this->_manageBox( $box );
      }
      //Bar dashboard
      else {
        $this->view( 'admin/box' );
      }
    }

    //}}
    //{{ _manageBox

    /**
     * Manage box
     *
     * @param object $box
     * @return void
     */
    protected function _manageBox( $box = false )
    {
      //
      //Including script
      wp_enqueue_media();
      wp_enqueue_script('wp-color-picker');
      wp_enqueue_style('wp-color-picker');

      $boxId = 0;
      if ( $box ) {
        $boxId = $box->ID;
      }
      $setting    = new IPPtak_Setting( $boxId, '__ipptak-box-setting' );
      $formAction = admin_url( 'admin-ajax.php' ) . '?doajax=1&ipptak=1&action=update_box';
      if ( $box )
      {
        $pageTitle   = __( 'Edit Box', IPPTAK_SLUG );
        $submitLabel = __( 'Save Change', IPPTAK_SLUG );
        $submitId    = 'ipptak-edit-box';
        $formId      = 'ipptak-form-box-update';
        $submitIcon  = 'floppy-o';
        $pageId      = IPPTAK_PAGENAME . '-box';

      } else
      {
        $pageTitle   = __( 'Add Box', IPPTAK_SLUG );
        $submitLabel = __( 'Add Box', IPPTAK_SLUG );
        $submitId    = 'ipptak-add-box';
        $formId      = 'ipptak-form-box-add';
        $submitIcon  = 'plus-circle';
        $pageId      = IPPTAK_PAGENAME . '-box';
      }
      $this->pageId      = $pageId;
      $this->pageTitle   = $pageTitle;
      $this->submitLabel = $submitLabel;
      $this->submitId    = $submitId;
      $this->formId      = $formId;
      $this->submitIcon  = $submitIcon;
      $this->setting     = $setting;
      $this->box         = $box;
      $this->boxId       = $boxId;
      $this->formAction  = $formAction;

      $tab = 'ipptak-section-general';
      if ( ! empty( $_REQUEST['tab'] )) {
        $tab = $_REQUEST['tab'];
      }
      $this->tab = $tab;

      //Render view
      $this->view( 'admin/box/main' );
    }

    //}}
    //{{ page

    /**
     * Manage pages viewer
     *
     * @return void
     */
    public function page()
    {
      $this->pageId = IPPTAK_PAGENAME . '-page';

      //Create new page
      if ( isset( $_GET['action'] ) && $_GET['action'] == 'create' )
      {
        $this->_managePage();
      }
      //Edit page
      elseif ( isset( $_GET['action'] ) && $_GET['action'] == 'edit' )
      {
        if ( empty( $_GET['id'] )) {
          wp_die( __('You attempted to edit an item that doesn&#8217;t exist. Perhaps it was deleted?', IPPTAK_SLUG ) );
        }
        $id = absint( $_GET['id'] );
        if ( ! $page = get_post( $id ) ) {
          wp_die( __('You attempted to edit an item that doesn&#8217;t exist. Perhaps it was deleted?', IPPTAK_SLUG ) );
        }
        $this->_managePage( $page );
      }
      //Bar dashboard
      else {
        $this->view( 'admin/page' );
      }
    }

    //}}
    //{{ _managePage

    /**
     * Manage page
     *
     * @param object $page
     * @return void
     */
    protected function _managePage( $pageData = false )
    {
      //
      //Including script
      wp_enqueue_media();
      wp_enqueue_script('wp-color-picker');
      wp_enqueue_style('wp-color-picker');

      $pageDataId = 0;
      if ( $pageData ) {
        $pageDataId = $pageData->ID;
      }
      $setting    = new IPPtak_Setting( $pageDataId, '__ipptak-page-setting' );
      $formAction = admin_url( 'admin-ajax.php' ) . '?doajax=1&ipptak=1&action=update_page';
      if ( $pageData )
      {
        $pageTitle   = __( 'Edit Page', IPPTAK_SLUG );
        $submitLabel = __( 'Save Change', IPPTAK_SLUG );
        $submitId    = 'ipptak-edit-page';
        $formId      = 'ipptak-form-page-update';
        $submitIcon  = 'floppy-o';
        $pageId      = IPPTAK_PAGENAME . '-page';

      } else
      {
        $pageTitle   = __( 'Add Page', IPPTAK_SLUG );
        $submitLabel = __( 'Add Page', IPPTAK_SLUG );
        $submitId    = 'ipptak-add-page';
        $formId      = 'ipptak-form-page-add';
        $submitIcon  = 'plus-circle';
        $pageId      = IPPTAK_PAGENAME . '-page';
      }
      $this->pageId      = $pageId;
      $this->pageTitle   = $pageTitle;
      $this->submitLabel = $submitLabel;
      $this->submitId    = $submitId;
      $this->formId      = $formId;
      $this->submitIcon  = $submitIcon;
      $this->setting     = $setting;
      $this->pageData    = $pageData;
      $this->pageDataId  = $pageDataId;
      $this->formAction  = $formAction;
      $this->bars        = $this->_getBars();
      $this->boxes       = $this->_getBoxes();

      $tab = 'ipptak-section-general';
      if ( ! empty( $_REQUEST['tab'] )) {
        $tab = $_REQUEST['tab'];
      }
      $this->tab = $tab;

      //
      //Permalink root
      $home = get_home_url();
      $path = get_option( '__ipptak_base_path', 'promo' );
      $root = $home . '/' . $path . '/';
      $this->permalink_root = $root;

      //Render view
      $this->view( 'admin/page/main' );
    }

    //}}
    //{{ setting

    /**
     * Setting page viewer
     *
     * @return void
     */
    public function setting()
    {
      $this->pageId = IPPTAK_PAGENAME . '-setting';
      $this->bars   = $this->_getBars();
      $this->boxes  = $this->_getBoxes();
      //Render view
      $this->view( 'admin/setting' );
    }

    //}}
    //{{ metabox

    /**
     * Metabox page viewer
     *
     * @return void
     */
    public function metabox( $post )
    {
      $this->post  = $post;
      $this->bars  = $this->_getBars();
      $this->boxes = $this->_getBoxes();

      //Render view
      $this->view( 'admin/metabox' );
    }

    //}}
    //{{ view

    /**
     * Get admin view file
     *
     * @param string $filename
     * @return void
     */
    public function view( $filename )
    {
      $path  = IPPTAK_VIEW;
      $path .= strtolower( $filename ) . '.php';
      if ( file_exists( $path )) {
        include( $path );
      }
    }

    //}}
    //{{ _getBars

    /**
     * Get bars list
     *
     * @return array
     */
    protected function _getBars()
    {
      $args = array(
        'orderby'        => 'post_title',
        'order'          => 'DESC',
        'post_type'      => 'ipptak_bar',
        'post_status'    => array('publish'),
        'posts_per_page' => -1,
        'paged'          => 1
      );
      $query = new WP_Query;
      $bars  = $query->query( $args );
      return $bars;
    }

    //}}
    //{{ _getBoxes

    /**
     * Get boxes list
     *
     * @return array
     */
    protected function _getBoxes()
    {
      $args = array(
        'orderby'        => 'post_title',
        'order'          => 'DESC',
        'post_type'      => 'ipptak_box',
        'post_status'    => array('publish'),
        'posts_per_page' => -1,
        'paged'          => 1
      );
      $query = new WP_Query;
      $boxes = $query->query( $args );
      return $boxes;
    }

    //}}
    //{{ _getPages

    /**
     * Get pages list
     *
     * @return array
     */
    protected function _getPages()
    {
      $args = array(
        'orderby'        => 'post_title',
        'order'          => 'DESC',
        'post_type'      => 'ipptak_page',
        'post_status'    => array('publish'),
        'posts_per_page' => -1,
        'paged'          => 1
      );
      $query = new WP_Query;
      $pages = $query->query( $args );
      return $pages;
    }

    //}}
  }
}
